@@ -22,7 +22,7 @@ from tornado.web import Application, FallbackHandler
 from .handlers import LiveReloadHandler, LiveReloadJSHandler
 from .handlers import ForceReloadHandler, StaticHandler
 from .watcher import Watcher
-from ._compat import text_types
+from ._compat import text_types, PY3
 from tornado.log import enable_pretty_logging
 enable_pretty_logging()
 
@@ -66,9 +66,10 @@ def shell(command, output=None, mode='w', cwd=None):
             logging.error(stderr)
             return stderr
         #: stdout is bytes, decode for python3
-        code = stdout.decode()
+        if PY3:
+            stdout = stdout.decode()
         with open(output, mode) as f:
-            f.write(code)
+            f.write(stdout)
 
     return run_shell
 
@@ -209,7 +210,7 @@ class Server(object):
         live.listen(liveport, address=host)
 
     def serve(self, port=5500, liveport=None, host=None, root=None, debug=True,
-              open_url=False, reload_delay=2):
+              open_url=False, restart_delay=2):
         """Start serve the server with the given port.
 
         :param port: serve on this port, default is 5500
@@ -220,6 +221,8 @@ class Server(object):
         """
         if host is None:
             host = ''
+        if root is not None:
+            self.root = root
 
         self.application(port, host, liveport=liveport, debug=debug)
         logging.getLogger().setLevel(logging.INFO)
@@ -235,7 +238,7 @@ class Server(object):
             threading.Thread(target=opener).start()
 
         try:
-            self.watcher._changes.append(('__livereload__', reload_delay))
+            self.watcher._changes.append(('__livereload__', restart_delay))
             IOLoop.instance().start()
         except KeyboardInterrupt:
             print('Shutting down...')
